# Prompt Engineering

This section covers various prompt engineering techniques and how you can use Mirascope to implement them.

Many of these recipes are adapted from techniques found in [this paper](https://arxiv.org/pdf/2406.06608) by [Learn Prompting](https://learnprompting.org/)

We recommend taking a look at the original papers for a full view of the technique and to better understand how we have adapted it to a more dynamic, reusable code environment.

!!! note "Some Techniques Are Not Included"

    We have covered various techniques, but not all of the ones included in the original paper due to various reasons. For example, some techniques require training separate models, which we've opted not to include. If there is a technique that you're really interested in that isn't covered, let us know and we'll see what we can do!
